bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 23. Aventiure
___________________________________________________ #### Auentv wie der kunec Ezele vn– div frowe C nach ir #### frivnden ze Wormez <sande>
| ### <In> also hohen eren daz ist alwar ### si <wonte> bi dem kunige vn–z in daz sibende iar ### di zit div kuniginne eines svnes was genesen ### des chunde der chunic Ezele nimmer vrolicher gewesn ### Sine wolde niht erwinden sine wrbe sint ### daz getovfet wrde daz Ezelen chint ### nach christenlichem rehte Ortliep wart <ez> genant ### si woldenz [54v]han ze herren vber elliv Ezelen lant
###### 1416 | ### Swaz ie gvoter tugende an froen Helchen lac ### des vleiz sich froe Chriemh' dar nach vil mannigen tac ### die site si lerte Herrat div ellende meit ### div hete tovgenliche nach ir frowen groziv leit
###### 1417 | ### Die fremden vn– die chunden die iahen da zehant ### daz nie milter frowe besæze ein kuniges lant ### noch deheiniv tirr lebte des iach man ir fvr war ### si erwarp ir lop vil grozen zen Hunin in daz zwelfte iar
| ### Si hete nv wol erchvnnen daz ir niemen widerstvnt ### als iz noch fursten wibe kuniges rechen tvont ### vn– daz si alle cite zwelf kunige vor ir sach ### do gedahtes maniger leide der ir da heime geschach
###### 1419 | ### Si gedaht ovch maniger eren von Nibelunge lant ### der si da was gewaltech vn– die ir Hagenen hant ### mit Sivrides tode hete gar benomen ### si gedaht ob im daz immer noch ze leide moehte chomen
###### 1420 | ### Si wnschte daz ir mvoter wære in Hunin lant ### ir trovmte daz ir Giselher gienge an der hant ### bi Ezele denn chunige si chvsten zaller stvont ### vil diche in senftem slafe sit wart in arebeiten chvnt
###### 1421 | ### Sine chvnde ovch nie vergezzen swie wol ir anders was ### ir starchen hercen leide in ir hercen si ez las ### mit iamer zallen stvnden daz man sit wol bevant ### do begvnde ir aber salwen von heizen trahen ir gewant
| ### Ez lac ir an dem hercen spat un– frvo ### wie man si ane schulde brahte der zvo ### daz si mvose minnen einen heiden man ### daz het ir frivnt Hagene vn– ovch Gunther getan
###### 1423 | ### Daz si daz rechen moehte des wnschtes alle tage ### ich bin nv wol so riche swem iz ovch missehage ### daz ich wol minen vinden mac gefvegen leit ### des wær et ich von Tronege Hagene gerne bereit
###### 1424 | ### Nach den getriwen iamert dichez herce min ### die mir da leide taten moeht ich bi den gesin ### so wrde noch errochen nmines mannes lip ### des ich vil chvme erbite sprach daz iamerhafte wip
###### 1425 | ### Ze liebe si do heten alle skuniges man ### die Chriemh' rechen daz was wol getan ### der kamern der pflac Ekkewart da von er frivnt gewan ### den Chriemh' willen mohte niemen verstan
| ### Si gedahte zallen citen si wolden kunic biten ### daz er ir des gunde mit gvetlichen siten ### daz man ir <frivnde> bræhte in der Hunin lant ### den argen willen niemen an frown Chriemh' ervant
###### 1427 | ### Do si eines nahtes bi dem kunige lac ### mit armen vmbevangen als er vil dicke pflac ### die edelen frowen trveten si was im so der lip ### do gedahte an ir vinde daz vil herliche wip
###### 1428 | ### Si sprach zv dem kunige vil lieber herre min ### ich <wolde> ivch biten gerne moeht [55r]ez mit fvege sin ### daz ich mich sehn liezet wie ich hete daz versolt ### ob ir minen frivnden wæret innechlichen holt
###### 1429 | ### Do sprach der kunich riche getriwe was sin mvot ### ich bringe ivch des wol innen swa lieb vn– gvot ### den helden widerfvere des mves ich frevde han ### wande ich von wibes minne bezzer frivnde nie gewan
###### 1430 | ### Do sprach div kuniginne iv ist daz wol geseit ### ich han vil hoher mage darvmbe ist mir so leit ### daz mich die so selten rvchent hie gesehn ### ich hore min die lvte niwan fvr ellende iehn
| ### Do sprach der kunic Ezele vil liebiv frowe min ### dvhtez si niht ze verre so ladet ich vber Rin ### swelh ir da gerne sæhit her in miniv lant ### div rede ir wol behagete da si den willen sin ervant
###### 1432 | ### Si sprach welt ir mir triwe leisten herre min ### so svlt ir boten senden von vns vber Rin ### sone bivte ich minen magen des ich da habe mvot ### so chvmt vns her ze lande vil manic edel ritter gvot
###### 1433 | ### Er sprach swenne ir gebietet so lazet ez geschehn ### irn dorftet iwer frivnde nie so gerne sehn ### als ich hie gesæhe der edeln voten chint ### mich mvet daz harte sere daz si vns so lange fremde sint
###### 1434 | ### Er sprach ob dv ez ratest vil liebiv frowe min ### di mine videlêre nach den frivnden din ### wil ich ze boten senden in Burgonden lant ### die Ezelen videlære hiez man bringe sa zehant
###### 1435 | ### Die knappen chomen beide da ir herre saz ### bi der kuniginne der kunic in sagte daz ### si solden boten werden in siner frivnde lant ### do hiez man in bereiten harte schiere gvot gewant
###### 1436 | ### vn– ir vartgesellen vier unt zweinzech man ### di mit in varn solden zen Burgonden dan ### in tet der chvnich Ezele chvnt den willen sin ### wie si laden solden Gvnthern mit den frivnden sin
| ### Do sprach der kunich riche ich chvndiv minen mvot ### ich enbivt minen frivnden lieb vn– allez gvot ### daz si gervchen riten her in miniv leit ### ich han so lieber geste harte selten noch bechant
###### 1438 | ### vn– ob si mines willen wellen iht began ### die mine chonemage daz si des niht lan ### sine chomen mir ze liebe zvo miner hochgecit ### wande vil der minen wenne an miner frowen magen lit
###### 1439 | ### Do sprach der knappen einer der hiez Swæmmelin ### benennet vns die hochgecit wenne sol div sin ### daz miner frowen frivnde dar zvo mvgen chomen ### des wart der kuniginne ir leides harte vil benomen
###### 1440 | ### Do sprach der kvnic here die minen hochgecit ### svlt ir ze Rine chvnden daz ir gewis des sit ### ze næhsten svnewenden so wil ich si han ### die vns mit triwen minnen daz si die reise niht enlan
| ### Wir tvon swaz [55v]ir gebietet sprach do Wærbelin ### in ir kemenaten bat si div kunigin ### bringen tovgenlichen da si <die> boten sprach ### da von sit manigem degene harte leide geschach
###### 1442 | ### Si sprach zen boten beiden ir dienet michel gvot ### ob ir minen willen tovgenlichen tvot ### so sagt swaz ich enbiete heim in vnser lant ### ich mache ivch gvtes riche vn– gibe iv herlich gewant
###### 1443 | ### Swaz ir der minen frivnde immer mvget gesehn ### ze Wormze bi dem Rine den svlt ir niht veriehn ### daz ir noch ie gesæhet betrvebet minen mvot ### vn– saget minen dienest den heleden <chven> vn– gvot
###### 1444 | ### Bitet daz si leisten daz in der kunic enbot ### vn– mich da mite scheiden von aller miner not ### die Hvnen mvgen wænen deich ane frivnde si ### ob ich ein ritter hieze ich wær in eteswenne bi
###### 1445 | ### Ir saget ovch Gernote dem lieben brvoder min ### daz im zer werlde niemen holder mvege sin ### vn– bitte in daz er fvere mit im in dizze lant ### die vnser besten frivnde deiz vns zen eren si gewant
###### 1446 | ### Vn– sagt ovch Giselhere er denche wol dar an ### daz er von minen schulden nie leides niht gewan ### des sêhen in vil gerne hie div ovgen min ### daz wolde ich immer mere hinz im diende sin
###### 1447 | ### Nv sagt ovch miner mvoter die ere die ich han ### vn– ob von Tronege Hagene welle dort bestan ### wer <si> danne solde wisen durch div lant ### dem sint die wege von kinde her zen Hvnin wol bekant
| ### Die boten niene wessen wa von daz was getan ### daz Hagene der chvene solde niht bestan ### hinder in Rine daz wart in sider leit ### mit im was manigem degene zem grimmem tode widerseit
###### 1449 | ### Boteschaft vn– brieve daz was nv gegebn ### si fvren gvotes riche vn– mohten schone lebn ### vrlovp gab in Ezele vn– ovch des <kuniges> wip ### in was mit richer wæte vil wol gezieret der lip
###### 1450 | ### Do der kunic Ezele von im gesande ### sine boten zvo dem Rine von manigem lande ### braht er vil der rechen zvo siner hochgecit ### der deheiner nimmer mere chom zvo sime lande <SIT>

<<< Übersicht <<< vorige Seite nächste Seite >>>